%{!?python_site: %global python_site %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(0)")}
# platform-dependent
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

# http://fedoraproject.org/wiki/Packaging:Guidelines#PIE
# http://fedoraproject.org/wiki/Hardened_Packages
%global _hardened_build 1

%if 0%{?fedora} >= 14
    %bcond_without systemd
%else
    %bcond_with systemd
%endif

# systemd wasn't set by the code above - so we're on old Fedora or we're not on Fedora at all
%if %{without systemd}
    %if 0%{?rhel} >= 7
        %bcond_without systemd
    %else
        %bcond_with systemd
    %endif
%endif

# build abrt-atomic subpackage
%bcond_without atomic

%ifarch aarch64
%define have_kexec_tools 0
%else
%define have_kexec_tools 1
%endif

# rpmbuild --define 'desktopvendor mystring'
%if "x%{desktopvendor}" == "x"
    %if %{with systemd}
        %define desktopvendor %(source /etc/os-release; echo ${ID})
    %else
        %if 0%{?rhel} >= 6
            %define desktopvendor redhat
        %else
            %if 0%{?suse_version}
                %define desktopvendor suse
            %else
                %define desktopvendor fedora
            %endif
        %endif
    %endif
%endif

# do not append package version to doc directory of subpackages in F20 and later; rhbz#993656
%if "%{_pkgdocdir}" == "%{_docdir}/%{name}"
    %define docdirversion %{nil}
%else
    %define docdirversion -%{version}
%endif

%define libreport_ver 2.9.1
%define satyr_ver 0.22

Summary: Automatic bug detection and reporting tool
Name: abrt
Version: 2.10.2
Release: 2%{?dist}
License: GPLv2+
Group: Applications/System
URL: https://abrt.readthedocs.org/
Source: https://github.com/abrt/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

# git format-patch %%{Version} --topo-order -N -M;
# i=1; for p in `ls 0*.patch`; do printf "Patch%04d: %s\n" $i $p; ((i++)); done

# don't remove this patch, packages in rawhide are not signed!
Patch0: disable-OpenGPGCheck-in-Fedora-Rawhide.patch

# '%%autosetup -S git' -> git
BuildRequires: git

BuildRequires: dbus-devel
BuildRequires: gtk3-devel
BuildRequires: glib2-devel >= 2.43
BuildRequires: rpm-devel >= 4.6
BuildRequires: desktop-file-utils
BuildRequires: libnotify-devel
#why? BuildRequires: file-devel
BuildRequires: python-devel
BuildRequires: python3-devel
BuildRequires: gettext
BuildRequires: libxml2-devel
BuildRequires: intltool
BuildRequires: libtool
BuildRequires: nss-devel
BuildRequires: asciidoc
BuildRequires: doxygen
BuildRequires: xmlto
BuildRequires: libreport-devel >= %{libreport_ver}
BuildRequires: satyr-devel >= %{satyr_ver}
BuildRequires: systemd-python
BuildRequires: python3-systemd
BuildRequires: augeas
BuildRequires: libselinux-devel
BuildRequires: python2-argcomplete
BuildRequires: python3-argcomplete
BuildRequires: python-argh
BuildRequires: python3-argh
BuildRequires: python-humanize
BuildRequires: python3-humanize

Requires: libreport >= %{libreport_ver}
Requires: satyr >= %{satyr_ver}

%if %{with systemd}
Requires: systemd-units
%endif
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-python3 = %{version}-%{release}
Requires(pre): shadow-utils
Requires: python3-augeas
Requires: python3-dbus
Requires: python3-dmidecode
Requires: libreport-plugin-ureport >= %{libreport_ver}
Recommends: libreport-plugin-systemd-journal

%description
%{name} is a tool to help users to detect defects in applications and
to create a bug report with all information needed by maintainer to fix it.
It uses plugin system to extend its functionality.

%package libs
Summary: Libraries for %{name}
Group: System Environment/Libraries

%description libs
Libraries for %{name}.

%package devel
Summary: Development libraries for %{name}
Group: Development/Libraries
Requires: abrt-libs = %{version}-%{release}

%description devel
Development libraries and headers for %{name}.

%package gui-libs
Summary: Libraries for %{name}-gui
Group: System Environment/Libraries

%description gui-libs
Libraries for %{name}-gui.

%package gui-devel
Summary: Development libraries for %{name}-gui
Group: Development/Libraries
Requires: abrt-gui-libs = %{version}-%{release}

%description gui-devel
Development libraries and headers for %{name}-gui.

%package gui
Summary: %{name}'s gui
Group: User Interface/Desktops
Requires: %{name} = %{version}-%{release}
Requires: %{name}-dbus = %{version}-%{release}
Requires: gnome-abrt
Requires: gsettings-desktop-schemas >= 3.15
BuildRequires: libreport-gtk-devel >= %{libreport_ver}
BuildRequires: gsettings-desktop-schemas-devel >= 3.15
# we used to have abrt-applet, now abrt-gui includes it:
Provides: abrt-applet = %{version}-%{release}
Obsoletes: abrt-applet < 0.0.5
Conflicts: abrt-applet < 0.0.5
Requires: abrt-libs = %{version}-%{release}
Requires: abrt-gui-libs = %{version}-%{release}

%description gui
GTK+ wizard for convenient bug reporting.

%package addon-coredump-helper
Summary: %{name}'s /proc/sys/kernel/core_pattern helper
Group: System Environment/Libraries
Requires: abrt-libs = %{version}-%{release}

%description addon-coredump-helper
This package contains hook for C/C++ crashed programs.

%package addon-ccpp
Summary: %{name}'s C/C++ addon
Group: System Environment/Libraries
Requires: cpio
BuildRequires: gdb-headless
BuildRequires: libcap-devel
Requires: gdb-headless
Requires: elfutils
%if 0%{!?rhel:1}
# abrt-action-perform-ccpp-analysis wants to run analyze_RetraceServer:
Requires: %{name}-retrace-client
%endif
Requires: %{name} = %{version}-%{release}
Requires: abrt-libs = %{version}-%{release}
Requires: %{name}-addon-coredump-helper = %{version}-%{release}
Requires: libreport-python3

%description addon-ccpp
This package contains %{name}'s C/C++ analyzer plugin.

%package addon-upload-watch
Summary: %{name}'s upload addon
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: abrt-libs = %{version}-%{release}

%description addon-upload-watch
This package contains hook for uploaded problems.

%package retrace-client
Summary: %{name}'s retrace client
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: xz
Requires: tar

%description retrace-client
This package contains the client application for Retrace server
which is able to analyze C/C++ crashes remotely.

%package addon-kerneloops
Summary: %{name}'s kerneloops addon
Group: System Environment/Libraries
BuildRequires: systemd-devel
Requires: curl
Requires: %{name} = %{version}-%{release}
%if 0%{!?rhel:1}
Requires: libreport-plugin-kerneloops >= %{libreport_ver}
%endif
Requires: abrt-libs = %{version}-%{release}

%description addon-kerneloops
This package contains plugin for collecting kernel crash information from
system log.

%package addon-xorg
Summary: %{name}'s Xorg addon
Group: System Environment/Libraries
Requires: curl
Requires: %{name} = %{version}-%{release}
Requires: abrt-libs = %{version}-%{release}

%description addon-xorg
This package contains plugin for collecting Xorg crash information from Xorg
log.

%if %{?have_kexec_tools} == 1
%package addon-vmcore
Summary: %{name}'s vmcore addon
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: abrt-addon-kerneloops
Requires: kexec-tools
Requires: abrt-python3
Requires: python3-augeas

%description addon-vmcore
This package contains plugin for collecting kernel crash information from
vmcore files.
%endif

%package addon-pstoreoops
Summary: %{name}'s pstore oops addon
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: abrt-libs = %{version}-%{release}
Requires: abrt-addon-kerneloops
Obsoletes: abrt-addon-uefioops < 2.1.7

%description addon-pstoreoops
This package contains plugin for collecting kernel oopses from pstore storage.

%package plugin-bodhi
Summary: %{name}'s bodhi plugin
BuildRequires: json-c-devel
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
BuildRequires: libreport-web-devel >= %{libreport_ver}
Obsoletes: libreport-plugin-bodhi > 0.0.1
Provides: libreport-plugin-bodhi = %{version}-%{release}

%description plugin-bodhi
Search for a new updates in bodhi server.

%package addon-python
Summary: %{name}'s addon for catching and analyzing Python exceptions
Group: System Environment/Libraries
Requires: python
Requires: %{name} = %{version}-%{release}
Requires: systemd-python
Requires: abrt-python

%description addon-python
This package contains python hook and python analyzer plugin for handling
uncaught exception in python programs.

%package addon-python3
Summary: %{name}'s addon for catching and analyzing Python 3 exceptions
Group: System Environment/Libraries
Requires: python3
Requires: %{name} = %{version}-%{release}
Requires: python3-systemd
Requires: abrt-python3

%description addon-python3
This package contains python 3 hook and python analyzer plugin for handling
uncaught exception in python 3 programs.

%package plugin-sosreport
Summary: %{name}'s plugin for building automatic sosreports
Requires: sos
Requires: %{name} = %{version}-%{release}

%description plugin-sosreport
This package contains a configuration snippet to enable automatic generation
of sosreports for abrt events.

%package plugin-machine-id
Summary: %{name}'s plugin to generate machine_id based off dmidecode
Requires: %{name} = %{version}-%{release}

%description plugin-machine-id
This package contains a configuration snippet to enable automatic generation
of machine_id for abrt events.

%package tui
Summary: %{name}'s command line interface
Group: User Interface/Desktops
Requires: %{name} = %{version}-%{release}
Requires: libreport-cli >= %{libreport_ver}
Requires: abrt-libs = %{version}-%{release}
Requires: abrt-dbus

%description tui
This package contains a simple command line client for processing abrt reports
in command line environment.

%package cli-ng
Summary: %{name}'s improved command line interface
Group: User Interface/Desktops
Requires: %{name} = %{version}-%{release}
Requires: libreport-cli >= %{libreport_ver}
Requires: abrt-libs = %{version}-%{release}
Requires: abrt-dbus
Requires: abrt-python
Requires: abrt-addon-ccpp
Requires: python-argh
Requires: python2-argcomplete
Requires: python-humanize
Requires: /usr/bin/register-python-argcomplete

%description cli-ng
New generation command line interface for ABRT

%package cli
Summary: Virtual package to make easy default installation on non-graphical environments
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: abrt-tui
Requires: abrt-addon-kerneloops
Requires: abrt-addon-pstoreoops
%if %{?have_kexec_tools} == 1
Requires: abrt-addon-vmcore
%endif
Requires: abrt-addon-ccpp
Requires: abrt-addon-python3
Requires: abrt-addon-xorg
%if 0%{?rhel}
Requires: libreport-rhel >= %{libreport_ver}
Requires: libreport-plugin-rhtsupport >= %{libreport_ver}
%else
Requires: abrt-retrace-client
Requires: abrt-plugin-bodhi
Requires: libreport-plugin-bugzilla >= %{libreport_ver}
Requires: libreport-plugin-logger >= %{libreport_ver}
Requires: libreport-plugin-ureport >= %{libreport_ver}

Requires: libreport-fedora >= %{libreport_ver}
%endif

%description cli
Virtual package to install all necessary packages for usage from command line
environment.

%package desktop
Summary: Virtual package to make easy default installation on desktop environments
Group: User Interface/Desktops
# This package gets installed when anything requests bug-buddy -
# happens when users upgrade Fn to Fn+1;
# or if user just wants "typical desktop installation".
# Installing abrt-desktop should result in the abrt which works without
# any tweaking in abrt.conf (IOW: all plugins mentioned there must be installed)
Requires: %{name} = %{version}-%{release}
Requires: abrt-addon-kerneloops
Requires: abrt-addon-pstoreoops
%if %{?have_kexec_tools} == 1
Requires: abrt-addon-vmcore
%endif
Requires: abrt-addon-ccpp
Requires: abrt-addon-python3
Requires: abrt-addon-xorg
# Default config of addon-ccpp requires gdb
Requires: gdb >= 7.8.1-31
Requires: elfutils
Requires: abrt-gui
Requires: gnome-abrt
%if 0%{?rhel}
Requires: libreport-rhel >= %{libreport_ver}
Requires: libreport-plugin-rhtsupport >= %{libreport_ver}
%else
Requires: abrt-retrace-client
Requires: abrt-plugin-bodhi
Requires: libreport-plugin-bugzilla >= %{libreport_ver}
Requires: libreport-plugin-logger >= %{libreport_ver}
Requires: libreport-plugin-ureport >= %{libreport_ver}
Requires: libreport-fedora >= %{libreport_ver}
%endif
#Requires: abrt-plugin-firefox
Provides: bug-buddy = 2.28.0

%description desktop
Virtual package to install all necessary packages for usage from desktop
environment.

%if %{with atomic}
%package atomic
Summary: Package to make easy default installation on Atomic hosts
Group: Applications/System
Requires: %{name}-addon-coredump-helper = %{version}-%{release}
Conflicts: %{name}-addon-ccpp
%endif

%description atomic
Package to install all necessary packages for usage from Atomic
hosts.

%package dbus
Summary: ABRT DBus service
Group: Applications/System
Requires: %{name} = %{version}-%{release}
BuildRequires: polkit-devel
Requires: abrt-libs = %{version}-%{release}

%description dbus
ABRT DBus service which provides org.freedesktop.problems API on dbus and
uses PolicyKit to authorize to access the problem data.


%package python
Summary: ABRT Python API
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-dbus = %{version}-%{release}
Requires: dbus-python
Requires: libreport-python
BuildRequires: python-nose
BuildRequires: python-sphinx
BuildRequires: libreport-python

%description python
High-level API for querying, creating and manipulating
problems handled by ABRT in Python.

%package python-doc
Summary: ABRT Python API Documentation
Group: Documentation
BuildArch: noarch
BuildRequires: python2-devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-python = %{version}-%{release}

%description python-doc
Examples and documentation for ABRT Python API.

%package python3
Summary: ABRT Python 3 API
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-dbus = %{version}-%{release}
Requires: python3-dbus
Requires: libreport-python3
BuildRequires: python3-nose
BuildRequires: python3-sphinx
BuildRequires: libreport-python3

%description python3
High-level API for querying, creating and manipulating
problems handled by ABRT in Python 3.

%package python3-doc
Summary: ABRT Python API Documentation
Group: Documentation
BuildArch: noarch
BuildRequires: python3-devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-python3 = %{version}-%{release}

%description python3-doc
Examples and documentation for ABRT Python 3 API.

%package console-notification
Summary: ABRT console notification script
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: %{name}-cli = %{version}-%{release}

%description console-notification
A small script which prints a count of detected problems when someone logs in
to the shell

%prep
# http://www.rpm.org/wiki/PackagerDocs/Autosetup
# Default '__scm_apply_git' is 'git apply && git commit' but this workflow
# doesn't allow us to create a new file within a patch, so we have to use
# 'git am' (see /usr/lib/rpm/macros for more details)
#%%define __scm_apply_git(qp:m:) %%{__git} am
%define __scm_apply_git(qp:m:) %{__git} am --exclude doc/design --exclude doc/project/abrt.tex
%autosetup -S git

%build
autoreconf --force --install
intltoolize --force --copy --automake
CFLAGS="%{optflags} -Werror" %configure --enable-doxygen-docs \
%ifnarch arm armhfp armv7hl armv7l aarch64
                                        --enable-native-unwinder \
%endif
%if %{without atomic}
                                        --without-atomic \
%endif
%if %{?have_kexec_tools} == 0
                                        --disable-addon-vmcore \
%endif
                                        --enable-dump-time-unwind \
                                        --disable-silent-rules

make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT \
             mandir=%{_mandir} \
             dbusabrtdocdir=%{_defaultdocdir}/%{name}-dbus%{docdirversion}/html/

%find_lang %{name}

# Remove byte-compiled python files generated by automake.
# automake uses system's python for all *.py files, even
# for those which needs to be byte-compiled with different
# version (python2/python3).
# rpm can do this work and use the appropriate python version.
find $RPM_BUILD_ROOT -name "*.py[co]" -delete

# remove all .la and .a files
find $RPM_BUILD_ROOT -name '*.la' -or -name '*.a' | xargs rm -f
mkdir -p ${RPM_BUILD_ROOT}/%{_initrddir}
mkdir -p $RPM_BUILD_ROOT/var/cache/abrt-di
mkdir -p $RPM_BUILD_ROOT/var/run/abrt
mkdir -p $RPM_BUILD_ROOT/var/spool/abrt
mkdir -p $RPM_BUILD_ROOT/var/spool/abrt-upload
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/abrt

desktop-file-install \
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
        src/applet/abrt-applet.desktop

ln -sf %{_datadir}/applications/abrt-applet.desktop ${RPM_BUILD_ROOT}%{_sysconfdir}/xdg/autostart/

# After everything is installed, remove info dir
rm -f %{buildroot}%{_infodir}/dir

# Install completions script in the right place
rm %{buildroot}%{_sysconfdir}/bash_completion.d/abrt.bash_completion
install -Dpm0644 src/cli-ng/abrt.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/abrt

%check
make check

%pre
#uidgid pair 173:173 reserved in setup rhbz#670231
%define abrt_gid_uid 173
getent group abrt >/dev/null || groupadd -f -g %{abrt_gid_uid} --system abrt
getent passwd abrt >/dev/null || useradd --system -g abrt -u %{abrt_gid_uid} -d /etc/abrt -s /sbin/nologin abrt
exit 0

%post
# $1 == 1 if install; 2 if upgrade
%systemd_post abrtd.service

%post addon-ccpp
# this is required for transition from 1.1.x to 2.x
# because /cache/abrt-di/* was created under root with root:root
# so 2.x fails when it tries to extract debuginfo there..
chown -R abrt:abrt %{_localstatedir}/cache/abrt-di
%systemd_post abrt-ccpp.service
%systemd_post abrt-journal-core.service
%journal_catalog_update

%post addon-kerneloops
%systemd_post abrt-oops.service
%journal_catalog_update

%post addon-xorg
%systemd_post abrt-xorg.service
%journal_catalog_update

%post addon-python
%journal_catalog_update

%post addon-python3
%journal_catalog_update

%if %{?have_kexec_tools} == 1
%post addon-vmcore
%systemd_post abrt-vmcore.service
%journal_catalog_update
%endif

%post addon-pstoreoops
%systemd_post abrt-pstoreoops.service

%post addon-upload-watch
%systemd_post abrt-upload-watch.service

%preun
%systemd_preun abrtd.service

%preun addon-ccpp
%systemd_preun abrt-ccpp.service
%systemd_preun abrt-journal-core.service

%preun addon-kerneloops
%systemd_preun abrt-oops.service

%preun addon-xorg
%systemd_preun abrt-xorg.service

%if %{?have_kexec_tools} == 1
%preun addon-vmcore
%systemd_preun abrt-vmcore.service
%endif

%preun addon-pstoreoops
%systemd_preun abrt-pstoreoops.service

%preun addon-upload-watch
%systemd_preun abrt-upload-watch.service

%postun
%systemd_postun_with_restart abrtd.service

%postun addon-ccpp
%systemd_postun_with_restart abrt-ccpp.service
%systemd_postun_with_restart abrt-journal-core.service

%postun addon-kerneloops
%systemd_postun_with_restart abrt-oops.service

%postun addon-xorg
%systemd_postun_with_restart abrt-xorg.service

%if %{?have_kexec_tools} == 1
%postun addon-vmcore
%systemd_postun_with_restart abrt-vmcore.service
%endif

%postun addon-pstoreoops
%systemd_postun_with_restart abrt-pstoreoops.service

%postun addon-upload-watch
%systemd_postun_with_restart abrt-upload-watch.service

%post gui
# update icon cache
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%if %{with atomic}
%post atomic
if [ -f /etc/abrt/plugins/CCpp.conf ]; then
    mv /etc/abrt/plugins/CCpp.conf /etc/abrt/plugins/CCpp.conf.rpmsave.atomic || exit 1;
fi
ln -sf /etc/abrt/plugins/CCpp_Atomic.conf /etc/abrt/plugins/CCpp.conf
if [ -f /usr/share/abrt/conf.d/plugins/CCpp.conf ]; then
    mv /usr/share/abrt/conf.d/plugins/CCpp.conf /usr/share/abrt/conf.d/plugins/CCpp.conf.rpmsave.atomic || exit 1;
fi
ln -sf /usr/share/abrt/conf.d/plugins/CCpp_Atomic.conf /usr/share/abrt/conf.d/plugins/CCpp.conf
%systemd_post abrt-coredump-helper.service

%preun atomic
if [ -L /etc/abrt/plugins/CCpp.conf ]; then
    rm /etc/abrt/plugins/CCpp.conf
fi
if [ -L /usr/share/abrt/conf.d/plugins/CCpp.conf ]; then
    rm /usr/share/abrt/conf.d/plugins/CCpp.conf
fi
if [ -f /etc/abrt/plugins/CCpp.conf.rpmsave.atomic ]; then
    mv /etc/abrt/plugins/CCpp.conf.rpmsave.atomic /etc/abrt/plugins/CCpp.conf || exit 1
fi
if [ -f  /usr/share/abrt/conf.d/plugins/CCpp.conf.rpmsave.atomic ]; then
    mv /usr/share/abrt/conf.d/plugins/CCpp.conf.rpmsave.atomic /usr/share/abrt/conf.d/plugins/CCpp.conf || exit 1
fi

%postun atomic
%systemd_postun_with_restart abrt-coredump-helper.service
%endif

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post gui-libs -p /sbin/ldconfig

%postun gui-libs -p /sbin/ldconfig

%postun gui
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
service abrtd condrestart >/dev/null 2>&1 || :

%posttrans addon-ccpp
# Migrate from abrt-ccpp.service to abrt-journal-core.service
# 'systemctl preset abrt-ccpp.service abrt-journal-core.service'
# is done only for installation by %systemd_post macro but not for package
# upgrade. Following lines affect changes in Fedora preset files in case of
# package upgrade and also starts abrt-journal-core.service and stops
# abrt-ccpp.service if abrt-ccpp.service is running.
# All this has to be done only once because some users want to use
# abrt-ccpp.service instead of the default abrt-journal-core.service.
# Hence we introduced a %{_localstatedir}/lib/abrt/abrt-migrated file to
# mark the migration was done.
if test ! -f %{_localstatedir}/lib/abrt/abrt-migrated ; then
    systemctl --no-reload preset abrt-ccpp.service >/dev/null 2>&1 || :
    systemctl --no-reload preset abrt-journal-core.service >/dev/null 2>&1 || :
    if service abrt-ccpp status >/dev/null 2>&1 ; then
        systemctl stop abrt-ccpp >/dev/null 2>&1 || :
        systemctl start abrt-journal-core >/dev/null 2>&1 || :
    fi
    touch %{_localstatedir}/lib/abrt/abrt-migrated
fi
systemctl try-restart abrt-journal-core >/dev/null 2>&1 || :
systemctl try-restart abrt-ccpp >/dev/null 2>&1 || :

%posttrans addon-kerneloops
service abrt-oops condrestart >/dev/null 2>&1 || :

%posttrans addon-xorg
service abrt-xorg condrestart >/dev/null 2>&1 || :

%if %{?have_kexec_tools} == 1
%posttrans addon-vmcore
service abrt-vmcore condrestart >/dev/null 2>&1 || :
# Copy the configuration file to plugin's directory
test -f /etc/abrt/abrt-harvest-vmcore.conf && {
    mv -b /etc/abrt/abrt-harvest-vmcore.conf /etc/abrt/plugins/vmcore.conf
}
exit 0
%endif

%posttrans addon-pstoreoops
service abrt-pstoreoops condrestart >/dev/null 2>&1 || :

%posttrans addon-upload-watch
service abrt-upload-watch condrestart >/dev/null 2>&1 || :

%posttrans gui
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%posttrans dbus
# Force abrt-dbus to restart like we do with the other services
killall abrt-dbus >/dev/null 2>&1 || :


%files -f %{name}.lang
%doc README.md COPYING
%if %{with systemd}
%{_unitdir}/abrtd.service
%{_tmpfilesdir}/abrt.conf
%else
%{_initrddir}/abrtd
%endif
%{_sbindir}/abrtd
%{_sbindir}/abrt-server
%{_sbindir}/abrt-auto-reporting
%{_libexecdir}/abrt-handle-event
%{_libexecdir}/abrt-action-ureport
%{_bindir}/abrt-handle-upload
%{_bindir}/abrt-action-notify
%{_mandir}/man1/abrt-action-notify.1*
%{_bindir}/abrt-action-save-package-data
%{_bindir}/abrt-action-save-container-data
%{_bindir}/abrt-watch-log
%{_bindir}/abrt-action-analyze-python
%{_bindir}/abrt-action-analyze-xorg
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.problems.daemon.conf
%config(noreplace) %{_sysconfdir}/%{name}/abrt-action-save-package-data.conf
%{_datadir}/%{name}/conf.d/abrt-action-save-package-data.conf
%config(noreplace) %{_sysconfdir}/%{name}/plugins/xorg.conf
%{_datadir}/%{name}/conf.d/plugins/xorg.conf
%{_mandir}/man5/abrt-xorg.conf.5*
%config(noreplace) %{_sysconfdir}/%{name}/gpg_keys.conf
%{_datadir}/%{name}/conf.d/gpg_keys.conf
%{_mandir}/man5/gpg_keys.conf.5*
%config(noreplace) %{_sysconfdir}/libreport/events.d/abrt_event.conf
%{_mandir}/man5/abrt_event.conf.5*
%config(noreplace) %{_sysconfdir}/libreport/events.d/smart_event.conf
%{_mandir}/man5/smart_event.conf.5*
%dir %attr(0751, root, abrt) %{_localstatedir}/spool/%{name}
%dir %attr(0700, abrt, abrt) %{_localstatedir}/spool/%{name}-upload
# abrtd runs as root
%dir %attr(0755, root, root) %{_localstatedir}/run/%{name}
%ghost %attr(0666, -, -) %{_localstatedir}/run/%{name}/abrt.socket
%ghost %attr(0644, -, -) %{_localstatedir}/run/%{name}/abrtd.pid

%{_mandir}/man1/abrt-handle-upload.1*
%{_mandir}/man1/abrt-server.1*
%{_mandir}/man1/abrt-action-save-package-data.1*
%{_mandir}/man1/abrt-watch-log.1*
%{_mandir}/man1/abrt-action-analyze-python.1*
%{_mandir}/man1/abrt-action-analyze-xorg.1*
%{_mandir}/man1/abrt-auto-reporting.1*
%{_mandir}/man8/abrtd.8*
%{_mandir}/man5/abrt-action-save-package-data.conf.5*
# {_mandir}/man5/pyhook.conf.5*

%files libs
%{_libdir}/libabrt.so.*
%config(noreplace) %{_sysconfdir}/%{name}/abrt.conf
%{_datadir}/%{name}/conf.d/abrt.conf
%{_mandir}/man5/abrt.conf.5*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/plugins
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/conf.d
%dir %{_datadir}/%{name}/conf.d/plugins

# filesystem package should own /usr/share/augeas/lenses directory
%{_datadir}/augeas/lenses/abrt.aug

%files devel
# The complex pattern below (instead of simlpy *) excludes Makefile{.am,.in}:
%doc apidoc/html/*.{html,png,css,js}
%{_includedir}/abrt/abrt-dbus.h
%{_includedir}/abrt/hooklib.h
%{_includedir}/abrt/libabrt.h
%{_includedir}/abrt/problem_api.h
%{_libdir}/libabrt.so
%{_libdir}/pkgconfig/abrt.pc

%files gui-libs
%{_libdir}/libabrt_gui.so.*

%files gui-devel
%{_includedir}/abrt/abrt-config-widget.h
%{_includedir}/abrt/system-config-abrt.h
%{_libdir}/libabrt_gui.so
%{_libdir}/pkgconfig/abrt_gui.pc

%files gui
%dir %{_datadir}/%{name}
# all glade, gtkbuilder and py files for gui
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/status/*
%{_datadir}/%{name}/icons/hicolor/*/status/*
%{_datadir}/%{name}/ui/*
%{_bindir}/abrt-applet
%{_bindir}/system-config-abrt
#%%{_bindir}/test-report
%{_datadir}/applications/abrt-applet.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/abrt-applet.desktop
%{_mandir}/man1/abrt-applet.1*
%{_mandir}/man1/system-config-abrt.1*

%files addon-coredump-helper
%{_libexecdir}/abrt-hook-ccpp
%{_sbindir}/abrt-install-ccpp-hook
%{_mandir}/man*/abrt-install-ccpp-hook.*

%files addon-ccpp
%dir %attr(0775, abrt, abrt) %{_localstatedir}/cache/abrt-di
%config(noreplace) %{_sysconfdir}/%{name}/plugins/CCpp.conf
%{_datadir}/%{name}/conf.d/plugins/CCpp.conf
%{_mandir}/man5/abrt-CCpp.conf.5*
%{_libexecdir}/abrt-gdb-exploitable
%{_journalcatalogdir}/abrt_ccpp.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_ccpp_format.conf
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_journal_ccpp_format.conf
%if %{with systemd}
%{_unitdir}/abrt-ccpp.service
%{_unitdir}/abrt-journal-core.service
%else
%{_initrddir}/abrt-ccpp
%endif

%dir %{_localstatedir}/lib/abrt

# attr(6755) ~= SETUID|SETGID
%attr(6755, abrt, abrt) %{_libexecdir}/abrt-action-install-debuginfo-to-abrt-cache

%{_bindir}/abrt-action-analyze-c
%{_bindir}/abrt-action-trim-files
%{_bindir}/abrt-action-analyze-core
%{_bindir}/abrt-action-analyze-vulnerability
%{_bindir}/abrt-action-install-debuginfo
%{_bindir}/abrt-action-generate-backtrace
%{_bindir}/abrt-action-generate-core-backtrace
%{_bindir}/abrt-action-analyze-backtrace
%{_bindir}/abrt-action-list-dsos
%{_bindir}/abrt-action-perform-ccpp-analysis
%{_bindir}/abrt-action-analyze-ccpp-local
%{_bindir}/abrt-dump-journal-core
%config(noreplace) %{_sysconfdir}/libreport/events.d/ccpp_event.conf
%{_mandir}/man5/ccpp_event.conf.5*
%config(noreplace) %{_sysconfdir}/libreport/events.d/gconf_event.conf
%{_mandir}/man5/gconf_event.conf.5*
%config(noreplace) %{_sysconfdir}/libreport/events.d/vimrc_event.conf
%{_mandir}/man5/vimrc_event.conf.5*
%{_datadir}/libreport/events/analyze_CCpp.xml
%{_datadir}/libreport/events/analyze_LocalGDB.xml
%{_datadir}/libreport/events/collect_xsession_errors.xml
%{_datadir}/libreport/events/collect_GConf.xml
%{_datadir}/libreport/events/collect_vimrc_user.xml
%{_datadir}/libreport/events/collect_vimrc_system.xml
%{_datadir}/libreport/events/post_report.xml
%{_mandir}/man*/abrt-action-analyze-c.*
%{_mandir}/man*/abrt-action-trim-files.*
%{_mandir}/man*/abrt-action-generate-backtrace.*
%{_mandir}/man*/abrt-action-generate-core-backtrace.*
%{_mandir}/man*/abrt-action-analyze-backtrace.*
%{_mandir}/man*/abrt-action-list-dsos.*
%{_mandir}/man*/abrt-action-install-debuginfo.*
%{_mandir}/man*/abrt-action-analyze-ccpp-local.*
%{_mandir}/man*/abrt-action-analyze-core.*
%{_mandir}/man*/abrt-action-analyze-vulnerability.*
%{_mandir}/man*/abrt-action-perform-ccpp-analysis.*
%{_mandir}/man*/abrt-dump-journal-core.*

%files addon-upload-watch
%{_sbindir}/abrt-upload-watch
%if %{with systemd}
%{_unitdir}/abrt-upload-watch.service
%else
%{_initrddir}/abrt-upload-watch
%endif
%{_mandir}/man*/abrt-upload-watch.*


%files retrace-client
%{_bindir}/abrt-retrace-client
%{_mandir}/man1/abrt-retrace-client.1*
%config(noreplace) %{_sysconfdir}/libreport/events.d/ccpp_retrace_event.conf
%{_mandir}/man5/ccpp_retrace_event.conf.5*
%{_datadir}/libreport/events/analyze_RetraceServer.xml

%files addon-kerneloops
%config(noreplace) %{_sysconfdir}/libreport/events.d/koops_event.conf
%{_journalcatalogdir}/abrt_koops.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_koops_format.conf
%{_mandir}/man5/koops_event.conf.5*
%config(noreplace) %{_sysconfdir}/%{name}/plugins/oops.conf
%{_datadir}/%{name}/conf.d/plugins/oops.conf
%if %{with systemd}
%{_unitdir}/abrt-oops.service
%else
%{_initrddir}/abrt-oops
%endif

%dir %{_localstatedir}/lib/abrt

%{_bindir}/abrt-dump-oops
%{_bindir}/abrt-dump-journal-oops
%{_bindir}/abrt-action-analyze-oops
%{_mandir}/man1/abrt-dump-oops.1*
%{_mandir}/man1/abrt-dump-journal-oops.1*
%{_mandir}/man1/abrt-action-analyze-oops.1*
%{_mandir}/man5/abrt-oops.conf.5*

%files addon-xorg
%config(noreplace) %{_sysconfdir}/libreport/events.d/xorg_event.conf
%{_journalcatalogdir}/abrt_xorg.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_xorg_format.conf
%{_mandir}/man5/xorg_event.conf.5*
%if %{with systemd}
%{_unitdir}/abrt-xorg.service
%else
%{_initrddir}/abrt-xorg
%endif
%{_bindir}/abrt-dump-xorg
%{_bindir}/abrt-dump-journal-xorg
%{_mandir}/man1/abrt-dump-xorg.1*
%{_mandir}/man1/abrt-dump-journal-xorg.1*

%if %{?have_kexec_tools} == 1
%files addon-vmcore
%config(noreplace) %{_sysconfdir}/libreport/events.d/vmcore_event.conf
%{_mandir}/man5/vmcore_event.conf.5*
%config(noreplace) %{_sysconfdir}/%{name}/plugins/vmcore.conf
%{_datadir}/%{name}/conf.d/plugins/vmcore.conf
%{_datadir}/libreport/events/analyze_VMcore.xml
%if %{with systemd}
%{_unitdir}/abrt-vmcore.service
%else
%{_initrddir}/abrt-vmcore
%endif
%{_sbindir}/abrt-harvest-vmcore
%{_bindir}/abrt-action-analyze-vmcore
%{_bindir}/abrt-action-check-oops-for-hw-error
%{_bindir}/abrt-action-check-oops-for-alt-component
%{_mandir}/man1/abrt-harvest-vmcore.1*
%{_mandir}/man5/abrt-vmcore.conf.5*
%{_mandir}/man1/abrt-action-analyze-vmcore.1*
%{_mandir}/man1/abrt-action-check-oops-for-hw-error.1*
%{_journalcatalogdir}/abrt_vmcore.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_vmcore_format.conf
%endif

%files addon-pstoreoops
%if %{with systemd}
%{_unitdir}/abrt-pstoreoops.service
%else
%{_initrddir}/abrt-pstoreoops
%endif
%{_sbindir}/abrt-harvest-pstoreoops
%{_bindir}/abrt-merge-pstoreoops
%{_mandir}/man1/abrt-harvest-pstoreoops.1*
%{_mandir}/man1/abrt-merge-pstoreoops.1*

%files addon-python
%config(noreplace) %{_sysconfdir}/%{name}/plugins/python.conf
%{_datadir}/%{name}/conf.d/plugins/python.conf
%{_mandir}/man5/abrt-python.conf.5*
# TODO? Do we need %%config(noreplace) in the below line too?
%config(noreplace) %{_sysconfdir}/libreport/events.d/python_event.conf
%{_journalcatalogdir}/abrt_python.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_python_format.conf
%{_mandir}/man5/python_event.conf.5*
%{python_sitearch}/abrt*.py*
%{python_sitearch}/abrt.pth

%files addon-python3
%config(noreplace) %{_sysconfdir}/%{name}/plugins/python3.conf
%{_datadir}/%{name}/conf.d/plugins/python3.conf
%{_mandir}/man5/abrt-python3.conf.5*
%config(noreplace) %{_sysconfdir}/libreport/events.d/python3_event.conf
%{_journalcatalogdir}/abrt_python3.catalog
%config(noreplace) %{_sysconfdir}/libreport/plugins/catalog_python3_format.conf
%{_mandir}/man5/python3_event.conf.5*
%{python3_sitearch}/abrt*
%{python3_sitearch}/__pycache__/abrt*

%files plugin-sosreport
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/libreport/events.d/sosreport_event.conf

%files plugin-machine-id
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/libreport/events.d/machine-id_event.conf
%{_libexecdir}/abrt-action-generate-machine-id

%files cli

%files tui
%{_bindir}/abrt-cli
%{_mandir}/man1/abrt-cli.1*

%files cli-ng
%{_datadir}/bash-completion/completions/abrt
%{_bindir}/abrt
%{python_sitearch}/abrtcli/
%{_mandir}/man1/abrt.1*

%files desktop

%if %{with atomic}
%files atomic
%config(noreplace) %{_sysconfdir}/%{name}/plugins/CCpp_Atomic.conf
%{_unitdir}/abrt-coredump-helper.service
%{_datadir}/%{name}/conf.d/plugins/CCpp_Atomic.conf
%config(noreplace) %{_sysconfdir}/%{name}/abrt-action-save-package-data.conf
%{_bindir}/abrt-action-save-package-data
%{_mandir}/man1/abrt-action-save-package-data.1*
%{_mandir}/man5/abrt-action-save-package-data.conf.5*
%endif

%files plugin-bodhi
%{_bindir}/abrt-bodhi
%{_bindir}/abrt-action-find-bodhi-update
%config(noreplace) %{_sysconfdir}/libreport/events.d/bodhi_event.conf
%{_datadir}/libreport/events/analyze_BodhiUpdates.xml
%{_mandir}/man1/abrt-bodhi.1*
%{_mandir}/man1/abrt-action-find-bodhi-update.1*

%files dbus
%{_sbindir}/abrt-dbus
%{_sbindir}/abrt-configuration
%{_mandir}/man8/abrt-dbus.8*
%{_mandir}/man8/abrt-configuration.8*
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/dbus-abrt.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.Problems2.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Problems2.Entry.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Problems2.Session.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Problems2.Task.xml
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.xml
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.abrt.xml
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.ccpp.xml
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.oops.xml
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.python.xml
%if %{?have_kexec_tools} == 1
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.vmcore.xml
%endif
%{_datadir}/dbus-1/interfaces/com.redhat.problems.configuration.xorg.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.problems.service
%{_datadir}/dbus-1/system-services/com.redhat.problems.configuration.service
%{_datadir}/polkit-1/actions/abrt_polkit.policy
%dir %{_defaultdocdir}/%{name}-dbus%{docdirversion}/
%dir %{_defaultdocdir}/%{name}-dbus%{docdirversion}/html/
%{_defaultdocdir}/%{name}-dbus%{docdirversion}/html/*.html
%{_defaultdocdir}/%{name}-dbus%{docdirversion}/html/*.css
%config(noreplace) %{_sysconfdir}/libreport/events.d/abrt_dbus_event.conf

%files python
%{python_sitearch}/problem/
%{_mandir}/man5/abrt-python.5*

%files python-doc
%{python_sitelib}/problem_examples

%files python3
%{python3_sitearch}/problem/
%{_mandir}/man5/abrt-python3.5*

%files python3-doc
%{python3_sitelib}/problem_examples

%files console-notification
%config(noreplace) %{_sysconfdir}/profile.d/abrt-console-notification.sh

%changelog
* Thu Apr 27 2017 Matej Habrnal <mhabrnal@redhat.com> 2.10.2-2
- create /var/lib/abrt because of abrt-migration

* Tue Apr 25 2017 Matej Habrnal <mhabrnal@redhat.com> 2.10.2-1
- Translation updates
- spec: introduce migration to abrt-journal-core
- abrt_event: Save cpuinfo in problem directories
- koops: Improve fatal MCE check when dumping backtrace
- lib: typo in header
- Spelling fixes
- Python 3.6 invalid escape sequence deprecation fix
- koops_event: add check to restrict reporting of MCEs

* Thu Mar 16 2017 Matej Habrnal <mhabrnal@redhat.com> 2.10.1-1
- bodhi: Remove dependency on hawkey
- spec: Remove dependency on hawkey
- build: do not upload tarball to fedorahosted.org
- spec: do not use fedorahosted.org as source
- plugins: introduce Machine ID and SOS report
- build: fix generating list of dependences in autogen.sh
- spec: start abrt-journal-core instead of abrt-ccpp
- build: fix scratch-build target
- a-a-ureport: fix calling of run_event_on_problem_dir
- spec: if using systemd, default to os-release ID for desktopvendor
- kernel: modify suspicious string "invalid opcode:"
- daemon: Allow rpm to be optional at build time
- spec: allow any compression of man pages
- spec: recommend libreport-plugin-systemd-journal on Fedoras
- doc: document selinux change needed for automatic deletion of reports
- ccpp: tell gdb to analyze saved binary image

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.10.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Jan 21 2017 Igor Gnatenko <ignatenko@redhat.com> - 2.10.0-3
- Rebuild for xmlrpc-c

* Wed Jan 18 2017 Matej Habrnal <mhabrnal@redhat.com> 2.10.0-2
- daemon: Allow rpm to be optional at build time
- modify kernel's suspicious string "invalid opcode:"
- fix calling of run_event_on_problem_dir in a-a-ureprt
- Resolves: #1413637, #1413451

* Mon Jan 02 2017 Matej Habrnal <mhabrnal@redhat.com> 2.10.0-1
- Translation updates
- build: make the release-* targets smarter
- Add CHANGELOG.md
- use run_event_on_problem_dir() helper for running events
- notify: do not require package element
- cli-ng: fix --fmt parameter
- python: create analyzer element in dumpdir
- lib: stop printing out a debug message 'adding: '
- cli: configure libreport to ignore not-reportable
- cli-ng: introduce verbose argument
- ccpp: configure package repositories for correct OS
- a-a-s-c-data: adapt to current docker
- a-a-s-c-data: correct detection of container type
- bodhi: factor out Bodhi updates lookup into a solo event
- problems2: update the documentation
- create crash_function and exception_type elements
- vmcore: /var/tmp/abrt is no longer a dump location
- events: add event report_systemd-journal to all addons
- abrt-action-notify: notify to systemd journal
- journal-catalog: add abrt's catalog source files
- ccpp: retain partial core_backtrace upon error
- daemon: properly shutdown socket connection
- daemon: close forgotten FD to /proc/[pid]
- ccpp: avoid running elfutils under root
- conf: increase MaxCrashReportsSize to 5GiB
- ccpp: fast dumping and abrt core limit
- doc: add a guide for ABRT hackers
- vmcore: read kdump.conf from an arbitrary location
- python2: stop generating dso_list in the process
- abrtd: save interesting process details
- a-a-s-package-data: add python3.6 to known Interpreters
- tree-wide: make path to GDB configurable
- a-a-ureport: print out exit codes in verbose mode
- daemon: stop replacing analyzer with type

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.9.0-2
- Rebuild for Python 3.6

* Fri Sep 09 2016 Jakub Filak <jfilak@redhat.com> 2.9.0-1
- dbus: Problems2 API implementation
- abrtd: change HTTP response code for duplicate problems to 303
- lib: normalize slashes of configured paths
- lib: make configuration paths alterable at runtime
- abrt-bodhi: use CCpp PackageManager configuration directive from configure
- cli: introduce unsafe reporting for not-reporable problems
- handle-event: stop creating post-create lock
- daemon: trigger dump location cleanup after detection
- hook-ccpp: dump own core file in debug mode
- fix memory leaks

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.2-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Jul 18 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.2-1
- Translation updates
- abrt-hook-ccpp: Fix mismatching argument
- Allow selinux to be optional at build time
- vmcore: use findmnt to get mountpoint
- vmcore: fix finding partitions by UUID and LABEL
- a-a-install-debuginfo: Exception may not have an argument errno
- koops: do not assume version has 3 levels
- Add ARM specific oops backtrace processing.
- examples: add oops-kernel-panic-hung-tasks-arm
- Add oops processing for kernel panics caused by hung tasks.
- abrt-hook-ccpp: save get_fsuid() return values in int variables
- Resolves: #1357264

* Wed May 25 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.1-1
- a-dump-journal-xorg: allow *libexec/X* to be executable element
- a-dump-journal-xorg: add '_COMM=gnome-shell' to journal filter
- build: update pkg names for systemd
- a-d-journal-core: save core dump bytes from the journal field
- a-d-journal-core: support lz4 compressed core dump files
- a-a-install-debuginfo: do not try to split None
- doc: improve documentation of AllowedGroups, AllowedUsers and IgnoredPaths
- testcase: add serial field to uReport check
- a-a-install-debuginfo: correct handling of DebuginfoLocation
- a-a-s-container-data: update docker container ID parser
- abrt-hook-ccpp: drop saving of container env vars
- a-console-notification: do not leak variables
- a-retrace-client: format security
- daemon: avoid infinite crash loops
- spec: drop abrt-action-save-kernel-data bits

* Fri Apr 08 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.0-5
- spec: README -> README.md
- Add basic documentation
- a-a-install-debuginfo: fix BrokenPipe error
- a-a-install-debuginfo: make tmpdir variable global

* Mon Mar 7 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.0-4
- python3 addon: workaround a bug in traceback

* Tue Feb 23 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.0-3
- translation updates
- blacklist Firefox's plugin-container
- turn off compat cores
- Resolves: #1308840

* Wed Feb 10 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.0-2
- drop %e from the core_pattern

* Wed Feb 03 2016 Matej Habrnal <mhabrnal@redhat.com> 2.8.0-1
- a-a-save-package-data: do not blacklist firefox
- Resolves: #1304310

* Tue Feb 02 2016 Matej Habrnal <mhabrnal@redhat.com> 2.7.2-1
- ccpp: add AllowedUsers and AllowedGroups feature
- ccpp: use executable name from pid
- a-a-c-o-f-hw-error: do not crash on invalid unicode
- configui: link GUI library with libabrt.so
- ccpp: unify log message of ignored crashes
- ccpp: add IgnoredPath option

* Mon Nov 23 2015 Jakub Filak <jfilak@redhat.com> 2.7.1-1
- CVE-2015-5287: switch owner of /var/spool/abrt to 'root'
- CVE-2015-5287: ccpp: save abrt core files only if DebugLevel > 0
- CVE-2015-5287: ccpp: save abrt core files only to new files
- CVE-2015-5287: abrt configuration: introduce DebugLevel
- CVE-2015-5273: a-a-i-d-to-abrt-cache: make own random temporary directory
- ccpp: make crashes of processes with locked memory not-reportable
- xorg: introduce tool abrt-dump-journal-xorg
- abrt-xorg.service: change due to abrt-dump-journal-xorg
- a-d-journal-core: set root owner for created dump directory
- spec: add missing man page for abrt-dump-journal-core
- Resolves: #1262252, #1284557

* Sat Nov 14 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@laptop> - 2.7.0-4
- Update requires on python-argcomplete
- Move completion script to /usr

* Fri Nov 6 2015 Jakub Filak <jfilak@redhat.com> - 2.7.0-3
- Rebuilt for Python3.5 rebuild

* Wed Oct 28 2015 Jakub Filak <jfilak@redhat.com> 2.7.0-2
- Fix broken problem details in abrt-cli/gnome-abrt

* Thu Oct 15 2015 Matej Habrnal <mhabrnal@redhat.com> 2.7.0-1
- cli-ng: initial
- bodhi: introduce wrapper for 'reporter-bugzilla -h' and 'abrt-bodhi'
- handle-event: remove obsolete workaround
- remove 'not needed' code
- doc: change /var/tmp/abrt to /var/spool/abrt
- doc: fix default DumpLocation in abrt.conf man page
- abrt-dump-xorg: support Xorg log backtraces prefixed by (EE)

* Tue Sep 15 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.2-8
- doc: actualize the abrt-bodhi man page
- bodhi: fix a segfault when testing an os-release opt for 'rawhide'

* Wed Aug 26 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.2-7
- bodhi: add parsing of error responses
- bodhi: add ignoring of Rawhide
- do not break the reporting if a-bodhi fails
- spec: add hawkey to BRs of abrt-bodhi
- introduce bodhi2 to abrt-bodhi
- convert all 'ex.message' stmts to 'str(ex)'
- don't start reporting of not-reportable problems
- add bash on the package blacklist
- Resolves #1250379

* Fri Aug 14 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.2-6
- ccpp - use global TID
- fix comment related to 'MakeCompatCore' option in CCpp.conf
- fix testing of DBus API return codes
- dbus-api: unify reporting of errors
- fix related to conditional compilation of man page
- abrt-auto-reporting: fix related to conditional compilation
- correct usage of abrt-gdb-exploitable

* Wed Jul 29 2015 Jakub Filak <jfilak@redhat.com> - 2.6.2-5
- Add python3-augeas to Requires: (FAF report #529272)

* Tue Jul 28 2015 Jakub Filak <jfilak@redhat.com> - 2.6.2-4
- Rebuild for rmplib : https://lists.fedoraproject.org/pipermail/devel/2015-July/212672.html

* Fri Jul 24 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.2-3
- read vmcore by chunks
- pass encoded Unicode to hashlib.sha1.update()
- abrt-merge-pstoreoops: merge files in descending order
- Resolves #1246459

* Wed Jul 22 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.2-2
- use gettext instead of lgettext in all python scripts

* Fri Jul 17 2015 Jakub Filak <jfilak@redhat.com> 2.6.2-1
- switch to Python 3
- reassign components of certain Kernel oopses to xorg-x11-drv-*
- de-prioritize post-mortem processes
- applet: do not crash if the new problem has no command_line
- abrt-hook-ccpp: do not crash if generate_core_backtrace fails
- cli: enable authentication for all commands

* Fri Jul 03 2015 Matej Habrnal <mhabrnal@redhat.com> 2.6.1-1
- keep the polkit authorization for all clients
- enable polkit authentication on command line
- use TID to find crash thread
- remove PyGObject from all Requires
- update version of gdb because of -ascending
- make it easier to find the backtrace of th crash thread
- save TID in the file 'tid'
- get TID from correct cmd line argument
- add option always generate backtrace locally
- add processor information to sosreport
- update abrt-cli man page
- Resolves #1217901

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 09 2015 Jakub Filak <jfilak@redhat.com> 2.6.0-1
- move the default dump location to /var/spool/abrt from /var/tmp/abrt
- hooks: use root for owner of all dump directories
- ccpp: do not unlink failed and big user cores
- ccpp: don't save the system logs by default
- ccpp: stop reading hs_error.log from /tmp
- ccpp: emulate selinux for creation of compat cores
- koops: don't save dmesg if kernel.dmesg_restrict=1
- dbus: validate passed arguments
- turn off exploring crashed process's root directories
- abrt-python: bug fixes and improvements
- fixes for CVE-2015-3315, CVE-2015-3142, CVE-2015-1869, CVE-2015-1870
- fixes for CVE-2015-3147, CVE-2015-3151, CVE-2015-3150, CVE-2015-3159
- spec: add abrt-dbus to Rs of abrt-python and abrt-cli
- spec: restart abrt-dbus in posttrans

* Wed May 20 2015 Matej Habrnal <mhabrnal@redhat.com> 2.5.1-3
- applet: fix problem info double free
- upload: validate and sanitize uploaded dump directories
- applet: switch to D-Bus methods
- lib: add new kernel taint flags
- abrt-auto-reporting: require rhtsupport.conf file only on RHEL
- doc, polkit: Spelling/grammar fixes
- applet: migrate Autoreporting options to GSettings
- config UI: read glade from a local file first
- config UI: Automatic reporting from GSettings
- Resolves: #1217901

* Mon Apr 13 2015 Jakub Filak <jfilak@redhat.com> 2.5.1-2
- Remove no longer needed posttrans scriptlet copying analyzer to type

* Thu Apr 09 2015 Jakub Filak <jfilak@redhat.com> 2.5.1-1
- Translation updates
- problem: use 'type' element instead of 'analyzer'
- cli-status: don't return 0 if there is a problem older than limit
- cli: use the DBus methods for getting problem information
- journal-oops: add an argument accepting journal directory
- lib: don't expect kernel's version '2.6.*' or '3.*.*'
- dbus: add new method to test existence of an element
- vmcore: generate 'reason' file in all cases
- applet: Don't show report button for unpackaged programs
- applet: get the list of problems through D-Bus service

* Fri Mar 20 2015 Jakub Filak <jfilak@redhat.com> 2.5.0-2
- applet: re-enable notifications of problems not-yet seen problems at start-up

* Wed Mar 18 2015 Jakub Filak <jfilak@redhat.com> 2.5.0-1
- dbus: add a new method GetProblemData
- abrt_event: run save package data event even if component exists
- a-a-s-container-data: add a new argument --root
- a-a-s-kernel-data: add --root argument
- journal-oops: add an argument similar to '--merge'
- ccpp: create the dump location from standalone hook
- retrace-client: stop failing on SSL2
- spec: changes for Atomic hosts
- ccpp: add support for multiple pkg mngrs
- Python 3 compatibility
- Don't allow users to list problems "by hand"
- spec: abrt-python requires libreport-python to build

* Fri Feb 20 2015 Jakub Filak <jfilak@redhat.com> - 2.4.0-1
- gracefully handle crashes in containers
- reworked abrt-applet's work-flow
- process unpackaged by default
- support collecting coredumps from systemd-coredumpctl
- search for log lines in journald more efficiently
- support sending micro-reports without the need to save coredump
- create a new package abrt-coredump-helper for Fedora Atomic

* Fri Nov 07 2014 Jakub Filak <jfilak@redhat.com> - 2.3.0-5
- koops: improve 'reason' text for page faults
- do not detect Firefox crashes
- make ABRT queiter
- update Package URL

* Tue Oct 14 2014 Jakub Filak <jfilak@redhat.com> - 2.3.0-4
- oops: get rid of invalid characters when dumping from journald

* Mon Oct 13 2014 Jakub Filak <jfilak@redhat.com> - 2.3.0-3
- applet: show package instead of duphash
- console-notifications: skip non-interactive shells

* Thu Oct 09 2014 Jakub Filak <jfilak@redhat.com> - 2.3.0-2
- console-notifications: use return instead of exit
